@@ -1,4 +1,4 @@
-// Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
+// Copyright 2018-2022 the Deno authors. All rights reserved. MIT license.
 
 use deno_core::anyhow::Context;
 use deno_core::error::{uri_error, AnyError};
@@ -130,7 +130,10 @@ pub fn resolve_from_cwd(path: &Path) -> Result<PathBuf, AnyError> {
 /// Checks if the path has extension Deno supports.
 pub fn is_supported_ext(path: &Path) -> bool {
   if let Some(ext) = get_extension(path) {
-    matches!(ext.as_str(), "ts" | "tsx" | "js" | "jsx" | "mjs")
+    matches!(
+      ext.as_str(),
+      "ts" | "tsx" | "js" | "jsx" | "mjs" | "mts" | "cjs" | "cts"
+    )
   } else {
     false
   }
@@ -147,6 +150,9 @@ pub fn is_supported_ext_fmt(path: &Path) -> bool {
         | "js"
         | "jsx"
         | "mjs"
+        | "mts"
+        | "cjs"
+        | "cts"
         | "json"
         | "jsonc"
         | "md"
@@ -163,26 +169,12 @@ pub fn is_supported_ext_fmt(path: &Path) -> bool {
 
 /// Checks if the path has a basename and extension Deno supports for tests.
 pub fn is_supported_test_path(path: &Path) -> bool {
-  use std::path::Component;
-  if let Some(Component::Normal(basename_os_str)) =
-    path.components().next_back()
-  {
-    let basename = basename_os_str.to_string_lossy();
-    basename.ends_with("_test.ts")
-      || basename.ends_with("_test.tsx")
-      || basename.ends_with("_test.js")
-      || basename.ends_with("_test.mjs")
-      || basename.ends_with("_test.jsx")
-      || basename.ends_with(".test.ts")
-      || basename.ends_with(".test.tsx")
-      || basename.ends_with(".test.js")
-      || basename.ends_with(".test.mjs")
-      || basename.ends_with(".test.jsx")
-      || basename == "test.ts"
-      || basename == "test.tsx"
-      || basename == "test.js"
-      || basename == "test.mjs"
-      || basename == "test.jsx"
+  if let Some(name) = path.file_stem() {
+    let basename = name.to_string_lossy();
+    (basename.ends_with("_test")
+      || basename.ends_with(".test")
+      || basename == "test")
+      && is_supported_ext(path)
   } else {
     false
   }
@@ -198,6 +190,9 @@ pub fn is_supported_test_ext(path: &Path) -> bool {
         | "js"
         | "jsx"
         | "mjs"
+        | "mts"
+        | "cjs"
+        | "cts"
         | "md"
         | "mkd"
         | "mkdn"
@@ -381,6 +376,20 @@ pub fn specifier_parent(specifier: &ModuleSpecifier) -> ModuleSpecifier {
   specifier
 }
 
+/// This function checks if input path has trailing slash or not. If input path
+/// has trailing slash it will return true else it will return false.
+pub fn path_has_trailing_slash(path: &Path) -> bool {
+  if let Some(path_str) = path.to_str() {
+    if cfg!(windows) {
+      path_str.ends_with('\\')
+    } else {
+      path_str.ends_with('/')
+    }
+  } else {
+    false
+  }
+}
+
 #[cfg(test)]
 mod tests {
   use super::*;
@@ -443,6 +452,9 @@ mod tests {
     assert!(is_supported_ext(Path::new("foo.JS")));
     assert!(is_supported_ext(Path::new("foo.JSX")));
     assert!(is_supported_ext(Path::new("foo.mjs")));
+    assert!(is_supported_ext(Path::new("foo.mts")));
+    assert!(is_supported_ext(Path::new("foo.cjs")));
+    assert!(is_supported_ext(Path::new("foo.cts")));
     assert!(!is_supported_ext(Path::new("foo.mjsx")));
   }
 
@@ -466,6 +478,9 @@ mod tests {
     assert!(is_supported_ext_fmt(Path::new("foo.JS")));
     assert!(is_supported_ext_fmt(Path::new("foo.JSX")));
     assert!(is_supported_ext_fmt(Path::new("foo.mjs")));
+    assert!(is_supported_ext_fmt(Path::new("foo.mts")));
+    assert!(is_supported_ext_fmt(Path::new("foo.cjs")));
+    assert!(is_supported_ext_fmt(Path::new("foo.cts")));
     assert!(!is_supported_ext_fmt(Path::new("foo.mjsx")));
     assert!(is_supported_ext_fmt(Path::new("foo.jsonc")));
     assert!(is_supported_ext_fmt(Path::new("foo.JSONC")));
@@ -493,6 +508,9 @@ mod tests {
     assert!(is_supported_test_ext(Path::new("foo.JS")));
     assert!(is_supported_test_ext(Path::new("foo.JSX")));
     assert!(is_supported_test_ext(Path::new("foo.mjs")));
+    assert!(is_supported_test_ext(Path::new("foo.mts")));
+    assert!(is_supported_test_ext(Path::new("foo.cjs")));
+    assert!(is_supported_test_ext(Path::new("foo.cts")));
     assert!(!is_supported_test_ext(Path::new("foo.mjsx")));
     assert!(!is_supported_test_ext(Path::new("foo.jsonc")));
     assert!(!is_supported_test_ext(Path::new("foo.JSONC")));
@@ -750,4 +768,29 @@ mod tests {
       assert_eq!(result.to_string(), expected);
     }
   }
+
+  #[test]
+  fn test_path_has_trailing_slash() {
+    #[cfg(not(windows))]
+    {
+      run_test("/Users/johndoe/Desktop/deno-project/target/", true);
+      run_test(r"/Users/johndoe/deno-project/target//", true);
+      run_test("/Users/johndoe/Desktop/deno-project", false);
+      run_test(r"/Users/johndoe/deno-project\", false);
+    }
+
+    #[cfg(windows)]
+    {
+      run_test(r"C:\test\deno-project\", true);
+      run_test(r"C:\test\deno-project\\", true);
+      run_test(r"C:\test\file.txt", false);
+      run_test(r"C:\test\file.txt/", false);
+    }
+
+    fn run_test(path_str: &str, expected: bool) {
+      let path = Path::new(path_str);
+      let result = path_has_trailing_slash(path);
+      assert_eq!(result, expected);
+    }
+  }
 }
