@@ -1,10 +1,10 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
-import { assert, assertEquals, unitTest } from "./test_util.ts";
+import { assert, assertEquals } from "./test_util.ts";
 
 // TODO(@kitsonk) remove when we are no longer patching TypeScript to have
 // these types available.
 
-unitTest(function typeCheckingEsNextArrayString() {
+Deno.test(function typeCheckingEsNextArrayString() {
   const a = "abcdef";
   assertEquals(a.at(-1), "f");
   const b = ["a", "b", "c", "d", "e", "f"];
@@ -13,13 +13,13 @@ unitTest(function typeCheckingEsNextArrayString() {
   assertEquals(b.findLastIndex((val) => typeof val === "string"), 5);
 });
 
-unitTest(function objectHasOwn() {
+Deno.test(function objectHasOwn() {
   const a = { a: 1 };
   assert(Object.hasOwn(a, "a"));
   assert(!Object.hasOwn(a, "b"));
 });
 
-unitTest(function errorCause() {
+Deno.test(function errorCause() {
   const e = new Error("test", { cause: "something" });
   assertEquals(e.cause, "something");
 });
