@@ -1,7 +1,7 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
-import { assert, unitTest } from "./test_util.ts";
+import { assert } from "./test_util.ts";
 
-unitTest(function internalsExists() {
+Deno.test(function internalsExists() {
   const {
     inspectArgs,
     // @ts-expect-error TypeScript (as of 3.7) does not support indexing namespaces by symbol
