@@ -7,7 +7,6 @@ import {
   assertThrows,
   deferred,
   delay,
-  unitTest,
 } from "./test_util.ts";
 
 let isCI: boolean;
@@ -17,7 +16,7 @@ try {
   isCI = true;
 }
 
-unitTest({ permissions: { net: true } }, function netTcpListenClose() {
+Deno.test({ permissions: { net: true } }, function netTcpListenClose() {
   const listener = Deno.listen({ hostname: "127.0.0.1", port: 3500 });
   assert(listener.addr.transport === "tcp");
   assertEquals(listener.addr.hostname, "127.0.0.1");
@@ -26,7 +25,7 @@ unitTest({ permissions: { net: true } }, function netTcpListenClose() {
   listener.close();
 });
 
-unitTest(
+Deno.test(
   {
     permissions: { net: true },
   },
@@ -43,7 +42,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -60,7 +59,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -77,8 +76,11 @@ unitTest(
   },
 );
 
-unitTest(
-  { ignore: Deno.build.os === "windows", permissions: { read: true } },
+Deno.test(
+  {
+    ignore: Deno.build.os === "windows",
+    permissions: { read: true, write: false },
+  },
   function netUnixListenWritePermission() {
     assertThrows(() => {
       const filePath = Deno.makeTempFileSync();
@@ -93,8 +95,11 @@ unitTest(
   },
 );
 
-unitTest(
-  { ignore: Deno.build.os === "windows", permissions: { read: true } },
+Deno.test(
+  {
+    ignore: Deno.build.os === "windows",
+    permissions: { read: true, write: false },
+  },
   function netUnixPacketListenWritePermission() {
     assertThrows(() => {
       const filePath = Deno.makeTempFileSync();
@@ -109,7 +114,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     permissions: { net: true },
   },
@@ -127,7 +132,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -142,12 +147,13 @@ unitTest(
     listener.close();
     await assertRejects(
       () => p,
-      Deno.errors.Interrupted,
+      Deno.errors.BadResource,
+      "Listener has been closed",
     );
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netTcpConcurrentAccept() {
     const listener = Deno.listen({ port: 4502 });
@@ -170,7 +176,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -180,7 +186,7 @@ unitTest(
     const listener = Deno.listen({ transport: "unix", path: filePath });
     let acceptErrCount = 0;
     const checkErr = (e: Error) => {
-      if (e instanceof Deno.errors.Interrupted) { // "operation canceled"
+      if (e.message === "Listener has been closed") {
         assertEquals(acceptErrCount, 1);
       } else if (e instanceof Deno.errors.Busy) { // "Listener already in use"
         acceptErrCount++;
@@ -197,7 +203,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { net: true } }, async function netTcpDialListen() {
+Deno.test({ permissions: { net: true } }, async function netTcpDialListen() {
   const listener = Deno.listen({ port: 3500 });
   listener.accept().then(
     async (conn) => {
@@ -232,7 +238,7 @@ unitTest({ permissions: { net: true } }, async function netTcpDialListen() {
   conn.close();
 });
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -271,7 +277,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netUdpSendReceive() {
     const alice = Deno.listenDatagram({ port: 3500, transport: "udp" });
@@ -301,7 +307,45 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
+  { permissions: { net: true } },
+  async function netUdpSendReceiveBroadcast() {
+    // Must bind sender to an address that can send to the broadcast address on MacOS.
+    // Macos will give us error 49 when sending the broadcast packet if we omit hostname here.
+    const alice = Deno.listenDatagram({
+      port: 3500,
+      transport: "udp",
+      hostname: "0.0.0.0",
+    });
+
+    const bob = Deno.listenDatagram({
+      port: 4501,
+      transport: "udp",
+      hostname: "0.0.0.0",
+    });
+    assert(bob.addr.transport === "udp");
+    assertEquals(bob.addr.port, 4501);
+    assertEquals(bob.addr.hostname, "0.0.0.0");
+
+    const broadcastAddr = { ...bob.addr, hostname: "255.255.255.255" };
+
+    const sent = new Uint8Array([1, 2, 3]);
+    const byteLength = await alice.send(sent, broadcastAddr);
+
+    assertEquals(byteLength, 3);
+    const [recvd, remote] = await bob.receive();
+    assert(remote.transport === "udp");
+    assertEquals(remote.port, 3500);
+    assertEquals(recvd.length, 3);
+    assertEquals(1, recvd[0]);
+    assertEquals(2, recvd[1]);
+    assertEquals(3, recvd[2]);
+    alice.close();
+    bob.close();
+  },
+);
+
+Deno.test(
   { permissions: { net: true } },
   async function netUdpConcurrentSendReceive() {
     const socket = Deno.listenDatagram({ port: 3500, transport: "udp" });
@@ -325,7 +369,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netUdpBorrowMutError() {
     const socket = Deno.listenDatagram({
@@ -340,7 +384,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -378,7 +422,7 @@ unitTest(
 );
 
 // TODO(piscisaureus): Enable after Tokio v0.3/v1.0 upgrade.
-unitTest(
+Deno.test(
   { ignore: true, permissions: { read: true, write: true } },
   async function netUnixPacketConcurrentSendReceive() {
     const filePath = await Deno.makeTempFile();
@@ -405,7 +449,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netTcpListenIteratorBreakClosesResource() {
     async function iterate(listener: Deno.Listener) {
@@ -435,7 +479,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netTcpListenCloseWhileIterating() {
     const listener = Deno.listen({ port: 8001 });
@@ -448,7 +492,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netUdpListenCloseWhileIterating() {
     const socket = Deno.listenDatagram({ port: 8000, transport: "udp" });
@@ -461,7 +505,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -478,7 +522,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os === "windows",
     permissions: { read: true, write: true },
@@ -498,7 +542,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { net: true } },
   async function netListenAsyncIterator() {
     const addr = { hostname: "127.0.0.1", port: 3500 };
@@ -529,7 +573,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     permissions: { net: true },
   },
@@ -562,7 +606,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     // https://github.com/denoland/deno/issues/11580
     ignore: Deno.build.os === "darwin" && isCI,
@@ -610,7 +654,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     permissions: { net: true },
   },
@@ -621,7 +665,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     ignore: Deno.build.os !== "linux",
     permissions: { read: true, write: true },
