@@ -4,23 +4,22 @@ import {
   assertEquals,
   assertRejects,
   assertThrows,
-  unitTest,
 } from "./test_util.ts";
 
-unitTest(async function permissionInvalidName() {
+Deno.test(async function permissionInvalidName() {
   await assertRejects(async () => {
     // deno-lint-ignore no-explicit-any
     await Deno.permissions.query({ name: "foo" as any });
   }, TypeError);
 });
 
-unitTest(async function permissionNetInvalidHost() {
+Deno.test(async function permissionNetInvalidHost() {
   await assertRejects(async () => {
     await Deno.permissions.query({ name: "net", host: ":" });
   }, URIError);
 });
 
-unitTest(async function permissionQueryReturnsEventTarget() {
+Deno.test(async function permissionQueryReturnsEventTarget() {
   const status = await Deno.permissions.query({ name: "hrtime" });
   assert(["granted", "denied", "prompt"].includes(status.state));
   let called = false;
@@ -32,7 +31,7 @@ unitTest(async function permissionQueryReturnsEventTarget() {
   assert(status === (await Deno.permissions.query({ name: "hrtime" })));
 });
 
-unitTest(async function permissionQueryForReadReturnsSameStatus() {
+Deno.test(async function permissionQueryForReadReturnsSameStatus() {
   const status1 = await Deno.permissions.query({
     name: "read",
     path: ".",
@@ -44,12 +43,12 @@ unitTest(async function permissionQueryForReadReturnsSameStatus() {
   assert(status1 === status2);
 });
 
-unitTest(function permissionsIllegalConstructor() {
+Deno.test(function permissionsIllegalConstructor() {
   assertThrows(() => new Deno.Permissions(), TypeError, "Illegal constructor.");
   assertEquals(Deno.Permissions.length, 0);
 });
 
-unitTest(function permissionStatusIllegalConstructor() {
+Deno.test(function permissionStatusIllegalConstructor() {
   assertThrows(
     () => new Deno.PermissionStatus(),
     TypeError,
@@ -58,7 +57,7 @@ unitTest(function permissionStatusIllegalConstructor() {
   assertEquals(Deno.PermissionStatus.length, 0);
 });
 
-unitTest(async function permissionURL() {
+Deno.test(async function permissionURL() {
   await Deno.permissions.query({
     name: "read",
     path: new URL(".", import.meta.url),
