@@ -4,16 +4,20 @@ import {
   assertEquals,
   assertStringIncludes,
   assertThrows,
-  unitTest,
 } from "./test_util.ts";
 
-unitTest({ permissions: { read: true } }, function runPermissions() {
-  assertThrows(() => {
-    Deno.run({ cmd: [Deno.execPath(), "eval", "console.log('hello world')"] });
-  }, Deno.errors.PermissionDenied);
-});
+Deno.test(
+  { permissions: { read: true, run: false } },
+  function runPermissions() {
+    assertThrows(() => {
+      Deno.run({
+        cmd: [Deno.execPath(), "eval", "console.log('hello world')"],
+      });
+    }, Deno.errors.PermissionDenied);
+  },
+);
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runSuccess() {
     const p = Deno.run({
@@ -30,7 +34,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runUrl() {
     const p = Deno.run({
@@ -51,7 +55,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runStdinRid0(): Promise<
     void
@@ -71,7 +75,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   function runInvalidStdio() {
     assertThrows(() =>
@@ -98,7 +102,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runCommandFailedWithCode() {
     const p = Deno.run({
@@ -112,7 +116,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     permissions: { run: true, read: true },
   },
@@ -137,7 +141,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { run: true } }, function runNotFound() {
+Deno.test({ permissions: { run: true } }, function runNotFound() {
   let error;
   try {
     Deno.run({ cmd: ["this file hopefully doesn't exist"] });
@@ -148,7 +152,7 @@ unitTest({ permissions: { run: true } }, function runNotFound() {
   assert(error instanceof Deno.errors.NotFound);
 });
 
-unitTest(
+Deno.test(
   { permissions: { write: true, run: true, read: true } },
   async function runWithCwdIsAsync() {
     const enc = new TextEncoder();
@@ -189,7 +193,7 @@ tryExit();
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runStdinPiped(): Promise<
     void
@@ -220,7 +224,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runStdoutPiped(): Promise<
     void
@@ -256,7 +260,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runStderrPiped(): Promise<
     void
@@ -292,7 +296,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runOutput() {
     const p = Deno.run({
@@ -310,7 +314,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runStderrOutput(): Promise<
     void
@@ -330,7 +334,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, write: true, read: true } },
   async function runRedirectStdoutStderr() {
     const tempDir = await Deno.makeTempDir();
@@ -363,7 +367,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, write: true, read: true } },
   async function runRedirectStdin() {
     const tempDir = await Deno.makeTempDir();
@@ -388,7 +392,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runEnv() {
     const p = Deno.run({
@@ -410,7 +414,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runClose() {
     const p = Deno.run({
@@ -433,7 +437,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function runKillAfterStatus() {
     const p = Deno.run({
@@ -461,7 +465,7 @@ unitTest(
   },
 );
 
-unitTest(function killPermissions() {
+Deno.test({ permissions: { run: false } }, function killPermissions() {
   assertThrows(() => {
     // Unlike the other test cases, we don't have permission to spawn a
     // subprocess we can safely kill. Instead we send SIGCONT to the current
@@ -471,7 +475,7 @@ unitTest(function killPermissions() {
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest(
+Deno.test(
   { ignore: Deno.build.os !== "windows", permissions: { run: true } },
   function negativePidInvalidWindows() {
     assertThrows(() => {
@@ -480,7 +484,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { ignore: Deno.build.os !== "windows", permissions: { run: true } },
   function invalidSignalNameWindows() {
     assertThrows(() => {
@@ -489,7 +493,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true } },
   async function killSuccess() {
     const p = Deno.run({
@@ -514,7 +518,7 @@ unitTest(
   },
 );
 
-unitTest({ permissions: { run: true, read: true } }, function killFailed() {
+Deno.test({ permissions: { run: true, read: true } }, function killFailed() {
   const p = Deno.run({
     cmd: [Deno.execPath(), "eval", "setTimeout(() => {}, 10000)"],
   });
@@ -529,7 +533,7 @@ unitTest({ permissions: { run: true, read: true } }, function killFailed() {
   p.close();
 });
 
-unitTest(
+Deno.test(
   { permissions: { run: true, read: true, env: true } },
   async function clearEnv(): Promise<void> {
     const p = Deno.run({
@@ -557,7 +561,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     permissions: { run: true, read: true },
     ignore: Deno.build.os === "windows",
@@ -588,7 +592,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   {
     permissions: { run: true, read: true },
     ignore: Deno.build.os === "windows",
