@@ -6,10 +6,10 @@ import {
   assertRejects,
   assertThrows,
   pathToAbsoluteFileUrl,
-  unitTest,
+  unreachable,
 } from "./test_util.ts";
 
-unitTest({ permissions: { read: true } }, function readFileSyncSuccess() {
+Deno.test({ permissions: { read: true } }, function readFileSyncSuccess() {
   const data = Deno.readFileSync("cli/tests/testdata/fixture.json");
   assert(data.byteLength > 0);
   const decoder = new TextDecoder("utf-8");
@@ -18,7 +18,7 @@ unitTest({ permissions: { read: true } }, function readFileSyncSuccess() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: true } }, function readFileSyncUrl() {
+Deno.test({ permissions: { read: true } }, function readFileSyncUrl() {
   const data = Deno.readFileSync(
     pathToAbsoluteFileUrl("cli/tests/testdata/fixture.json"),
   );
@@ -29,19 +29,19 @@ unitTest({ permissions: { read: true } }, function readFileSyncUrl() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: false } }, function readFileSyncPerm() {
+Deno.test({ permissions: { read: false } }, function readFileSyncPerm() {
   assertThrows(() => {
     Deno.readFileSync("cli/tests/testdata/fixture.json");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest({ permissions: { read: true } }, function readFileSyncNotFound() {
+Deno.test({ permissions: { read: true } }, function readFileSyncNotFound() {
   assertThrows(() => {
     Deno.readFileSync("bad_filename");
   }, Deno.errors.NotFound);
 });
 
-unitTest({ permissions: { read: true } }, async function readFileUrl() {
+Deno.test({ permissions: { read: true } }, async function readFileUrl() {
   const data = await Deno.readFile(
     pathToAbsoluteFileUrl("cli/tests/testdata/fixture.json"),
   );
@@ -52,7 +52,7 @@ unitTest({ permissions: { read: true } }, async function readFileUrl() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: true } }, async function readFileSuccess() {
+Deno.test({ permissions: { read: true } }, async function readFileSuccess() {
   const data = await Deno.readFile("cli/tests/testdata/fixture.json");
   assert(data.byteLength > 0);
   const decoder = new TextDecoder("utf-8");
@@ -61,19 +61,19 @@ unitTest({ permissions: { read: true } }, async function readFileSuccess() {
   assertEquals(pkg.name, "deno");
 });
 
-unitTest({ permissions: { read: false } }, async function readFilePerm() {
+Deno.test({ permissions: { read: false } }, async function readFilePerm() {
   await assertRejects(async () => {
     await Deno.readFile("cli/tests/testdata/fixture.json");
   }, Deno.errors.PermissionDenied);
 });
 
-unitTest({ permissions: { read: true } }, function readFileSyncLoop() {
+Deno.test({ permissions: { read: true } }, function readFileSyncLoop() {
   for (let i = 0; i < 256; i++) {
     Deno.readFileSync("cli/tests/testdata/fixture.json");
   }
 });
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   async function readFileDoesNotLeakResources() {
     const resourcesBefore = Deno.resources();
@@ -82,7 +82,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   function readFileSyncDoesNotLeakResources() {
     const resourcesBefore = Deno.resources();
@@ -91,20 +91,61 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true } },
   async function readFileWithAbortSignal() {
     const ac = new AbortController();
     queueMicrotask(() => ac.abort());
-    await assertRejects(async () => {
-      await Deno.readFile("cli/tests/testdata/fixture.json", {
-        signal: ac.signal,
-      });
-    });
+    await assertRejects(
+      async () => {
+        await Deno.readFile("cli/tests/testdata/fixture.json", {
+          signal: ac.signal,
+        });
+      },
+      (error: Error) => {
+        assert(error instanceof DOMException);
+        assertEquals(error.name, "AbortError");
+      },
+    );
   },
 );
 
-unitTest(
+Deno.test(
+  { permissions: { read: true } },
+  async function readFileWithAbortSignalReason() {
+    const ac = new AbortController();
+    const abortReason = new Error();
+    queueMicrotask(() => ac.abort(abortReason));
+    await assertRejects(
+      async () => {
+        await Deno.readFile("cli/tests/testdata/fixture.json", {
+          signal: ac.signal,
+        });
+      },
+      (error: Error) => {
+        assertEquals(error, abortReason);
+      },
+    );
+  },
+);
+
+Deno.test(
+  { permissions: { read: true } },
+  async function readFileWithAbortSignalPrimitiveReason() {
+    const ac = new AbortController();
+    queueMicrotask(() => ac.abort("Some string"));
+    try {
+      await Deno.readFile("cli/tests/testdata/fixture.json", {
+        signal: ac.signal,
+      });
+      unreachable();
+    } catch (e) {
+      assertEquals(e, "Some string");
+    }
+  },
+);
+
+Deno.test(
   { permissions: { read: true }, ignore: Deno.build.os !== "linux" },
   async function readFileProcFs() {
     const data = await Deno.readFile("/proc/self/stat");
@@ -112,7 +153,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function readFileExtendedDuringRead() {
     // Write 128MB file
@@ -131,7 +172,7 @@ unitTest(
   },
 );
 
-unitTest(
+Deno.test(
   { permissions: { read: true, write: true } },
   async function readFile0LengthExtendedDuringRead() {
     // Write 0 byte file
